# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class alertFilter(object):

    def __init__(self, zap):
        self.zap = zap

    def alert_filter_list(self, contextid):
        """
        Lists the alert filters of the context with the given ID.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/view/alertFilterList/', {'contextId': contextid})))

    @property
    def global_alert_filter_list(self):
        """
        Lists the global alert filters.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/view/globalAlertFilterList/')))

    def add_alert_filter(self, contextid, ruleid, newlevel, url=None, urlisregex=None, parameter=None, enabled=None, parameterisregex=None, attack=None, attackisregex=None, evidence=None, evidenceisregex=None, apikey=''):
        """
        Adds a new alert filter for the context with the given ID. 
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'contextId': contextid, 'ruleId': ruleid, 'newLevel': newlevel, 'apikey': apikey}
        if url is not None:
            params['url'] = url
        if urlisregex is not None:
            params['urlIsRegex'] = urlisregex
        if parameter is not None:
            params['parameter'] = parameter
        if enabled is not None:
            params['enabled'] = enabled
        if parameterisregex is not None:
            params['parameterIsRegex'] = parameterisregex
        if attack is not None:
            params['attack'] = attack
        if attackisregex is not None:
            params['attackIsRegex'] = attackisregex
        if evidence is not None:
            params['evidence'] = evidence
        if evidenceisregex is not None:
            params['evidenceIsRegex'] = evidenceisregex
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/action/addAlertFilter/', params)))

    def remove_alert_filter(self, contextid, ruleid, newlevel, url=None, urlisregex=None, parameter=None, enabled=None, parameterisregex=None, attack=None, attackisregex=None, evidence=None, evidenceisregex=None, apikey=''):
        """
        Removes an alert filter from the context with the given ID.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'contextId': contextid, 'ruleId': ruleid, 'newLevel': newlevel, 'apikey': apikey}
        if url is not None:
            params['url'] = url
        if urlisregex is not None:
            params['urlIsRegex'] = urlisregex
        if parameter is not None:
            params['parameter'] = parameter
        if enabled is not None:
            params['enabled'] = enabled
        if parameterisregex is not None:
            params['parameterIsRegex'] = parameterisregex
        if attack is not None:
            params['attack'] = attack
        if attackisregex is not None:
            params['attackIsRegex'] = attackisregex
        if evidence is not None:
            params['evidence'] = evidence
        if evidenceisregex is not None:
            params['evidenceIsRegex'] = evidenceisregex
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/action/removeAlertFilter/', params)))

    def add_global_alert_filter(self, ruleid, newlevel, url=None, urlisregex=None, parameter=None, enabled=None, parameterisregex=None, attack=None, attackisregex=None, evidence=None, evidenceisregex=None, apikey=''):
        """
        Adds a new global alert filter. 
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'ruleId': ruleid, 'newLevel': newlevel, 'apikey': apikey}
        if url is not None:
            params['url'] = url
        if urlisregex is not None:
            params['urlIsRegex'] = urlisregex
        if parameter is not None:
            params['parameter'] = parameter
        if enabled is not None:
            params['enabled'] = enabled
        if parameterisregex is not None:
            params['parameterIsRegex'] = parameterisregex
        if attack is not None:
            params['attack'] = attack
        if attackisregex is not None:
            params['attackIsRegex'] = attackisregex
        if evidence is not None:
            params['evidence'] = evidence
        if evidenceisregex is not None:
            params['evidenceIsRegex'] = evidenceisregex
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/action/addGlobalAlertFilter/', params)))

    def remove_global_alert_filter(self, ruleid, newlevel, url=None, urlisregex=None, parameter=None, enabled=None, parameterisregex=None, attack=None, attackisregex=None, evidence=None, evidenceisregex=None, apikey=''):
        """
        Removes a global alert filter.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'ruleId': ruleid, 'newLevel': newlevel, 'apikey': apikey}
        if url is not None:
            params['url'] = url
        if urlisregex is not None:
            params['urlIsRegex'] = urlisregex
        if parameter is not None:
            params['parameter'] = parameter
        if enabled is not None:
            params['enabled'] = enabled
        if parameterisregex is not None:
            params['parameterIsRegex'] = parameterisregex
        if attack is not None:
            params['attack'] = attack
        if attackisregex is not None:
            params['attackIsRegex'] = attackisregex
        if evidence is not None:
            params['evidence'] = evidence
        if evidenceisregex is not None:
            params['evidenceIsRegex'] = evidenceisregex
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/action/removeGlobalAlertFilter/', params)))

    def apply_all(self, apikey=''):
        """
        Applies all currently enabled Global and Context alert filters.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/action/applyAll/', {'apikey': apikey})))

    def apply_context(self, apikey=''):
        """
        Applies all currently enabled Context alert filters.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/action/applyContext/', {'apikey': apikey})))

    def apply_global(self, apikey=''):
        """
        Applies all currently enabled Global alert filters.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/action/applyGlobal/', {'apikey': apikey})))

    def test_all(self, apikey=''):
        """
        Tests all currently enabled Global and Context alert filters.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/action/testAll/', {'apikey': apikey})))

    def test_context(self, apikey=''):
        """
        Tests all currently enabled Context alert filters.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/action/testContext/', {'apikey': apikey})))

    def test_global(self, apikey=''):
        """
        Tests all currently enabled Global alert filters.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alertFilter/action/testGlobal/', {'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class sessionManagement(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def get_supported_session_management_methods(self):
        """
        Gets the name of the session management methods.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'sessionManagement/view/getSupportedSessionManagementMethods/')))

    def get_session_management_method_config_params(self, methodname):
        """
        Gets the configuration parameters for the session management method with the given name.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'sessionManagement/view/getSessionManagementMethodConfigParams/', {'methodName': methodname})))

    def get_session_management_method(self, contextid):
        """
        Gets the name of the session management method for the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'sessionManagement/view/getSessionManagementMethod/', {'contextId': contextid})))

    def set_session_management_method(self, contextid, methodname, methodconfigparams=None, apikey=''):
        """
        Sets the session management method for the context with the given ID.
        """
        params = {'contextId': contextid, 'methodName': methodname, 'apikey': apikey}
        if methodconfigparams is not None:
            params['methodConfigParams'] = methodconfigparams
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'sessionManagement/action/setSessionManagementMethod/', params)))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class acsrf(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def option_tokens_names(self):
        """
        Lists the names of all anti-CSRF tokens
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'acsrf/view/optionTokensNames/')))

    @property
    def option_partial_matching_enabled(self):
        """
        Define if ZAP should detect CSRF tokens by searching for partial matches
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'acsrf/view/optionPartialMatchingEnabled/')))

    def add_option_token(self, string, apikey=''):
        """
        Adds an anti-CSRF token with the given name, enabled by default
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'acsrf/action/addOptionToken/', {'String': string, 'apikey': apikey})))

    def remove_option_token(self, string, apikey=''):
        """
        Removes the anti-CSRF token with the given name
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'acsrf/action/removeOptionToken/', {'String': string, 'apikey': apikey})))

    def set_option_partial_matching_enabled(self, boolean, apikey=''):
        """
        Define if ZAP should detect CSRF tokens by searching for partial matches.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'acsrf/action/setOptionPartialMatchingEnabled/', {'Boolean': boolean, 'apikey': apikey})))

    def gen_form(self, hrefid, actionurl=None, apikey=''):
        """
        Generate a form for testing lack of anti-CSRF tokens - typically invoked via ZAP
        """
        params = {'hrefId': hrefid, 'apikey': apikey}
        if actionurl is not None:
            params['actionUrl'] = actionurl
        return (self.zap._request_other(self.zap.base_other + 'acsrf/other/genForm/', params))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class stats(object):

    def __init__(self, zap):
        self.zap = zap

    def stats(self, keyprefix=None):
        """
        Statistics
        """
        params = {}
        if keyprefix is not None:
            params['keyPrefix'] = keyprefix
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/view/stats/', params)))

    def all_sites_stats(self, keyprefix=None):
        """
        Gets all of the site based statistics, optionally filtered by a key prefix
        """
        params = {}
        if keyprefix is not None:
            params['keyPrefix'] = keyprefix
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/view/allSitesStats/', params)))

    def site_stats(self, site, keyprefix=None):
        """
        Gets all of the global statistics, optionally filtered by a key prefix
        """
        params = {'site': site}
        if keyprefix is not None:
            params['keyPrefix'] = keyprefix
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/view/siteStats/', params)))

    @property
    def option_statsd_host(self):
        """
        Gets the Statsd service hostname
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/view/optionStatsdHost/')))

    @property
    def option_statsd_port(self):
        """
        Gets the Statsd service port
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/view/optionStatsdPort/')))

    @property
    def option_statsd_prefix(self):
        """
        Gets the prefix to be applied to all stats sent to the configured Statsd service
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/view/optionStatsdPrefix/')))

    @property
    def option_in_memory_enabled(self):
        """
        Returns 'true' if in memory statistics are enabled, otherwise returns 'false'
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/view/optionInMemoryEnabled/')))

    @property
    def option_statsd_enabled(self):
        """
        Returns 'true' if a Statsd server has been correctly configured, otherwise returns 'false'
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/view/optionStatsdEnabled/')))

    def clear_stats(self, keyprefix=None, apikey=''):
        """
        Clears all of the statistics
        """
        params = {'apikey': apikey}
        if keyprefix is not None:
            params['keyPrefix'] = keyprefix
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/action/clearStats/', params)))

    def set_option_statsd_host(self, string, apikey=''):
        """
        Sets the Statsd service hostname, supply an empty string to stop using a Statsd service
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/action/setOptionStatsdHost/', {'String': string, 'apikey': apikey})))

    def set_option_statsd_prefix(self, string, apikey=''):
        """
        Sets the prefix to be applied to all stats sent to the configured Statsd service
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/action/setOptionStatsdPrefix/', {'String': string, 'apikey': apikey})))

    def set_option_in_memory_enabled(self, boolean, apikey=''):
        """
        Sets whether in memory statistics are enabled
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/action/setOptionInMemoryEnabled/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_statsd_port(self, integer, apikey=''):
        """
        Sets the Statsd service port
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'stats/action/setOptionStatsdPort/', {'Integer': integer, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class ascan(object):

    def __init__(self, zap):
        self.zap = zap

    def status(self, scanid=None):
        """
        
        """
        params = {}
        if scanid is not None:
            params['scanId'] = scanid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/status/', params)))

    def scan_progress(self, scanid=None):
        """
        
        """
        params = {}
        if scanid is not None:
            params['scanId'] = scanid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/scanProgress/', params)))

    def messages_ids(self, scanid):
        """
        Gets the IDs of the messages sent during the scan with the given ID. A message can be obtained with 'message' core view.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/messagesIds/', {'scanId': scanid})))

    def alerts_ids(self, scanid):
        """
        Gets the IDs of the alerts raised during the scan with the given ID. An alert can be obtained with 'alert' core view.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/alertsIds/', {'scanId': scanid})))

    @property
    def scans(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/scans/')))

    @property
    def scan_policy_names(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/scanPolicyNames/')))

    @property
    def excluded_from_scan(self):
        """
        Gets the regexes of URLs excluded from the active scans.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/excludedFromScan/')))

    def scanners(self, scanpolicyname=None, policyid=None):
        """
        Gets the scan rules, optionally, of the given scan policy or scanner policy/category ID.
        """
        params = {}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        if policyid is not None:
            params['policyId'] = policyid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/scanners/', params)))

    def policies(self, scanpolicyname=None, policyid=None):
        """
        
        """
        params = {}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        if policyid is not None:
            params['policyId'] = policyid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/policies/', params)))

    @property
    def attack_mode_queue(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/attackModeQueue/')))

    @property
    def excluded_params(self):
        """
        Gets all the parameters that are excluded. For each parameter the following are shown: the name, the URL, and the parameter type.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/excludedParams/')))

    @property
    def option_excluded_param_list(self):
        """
        Use view excludedParams instead.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionExcludedParamList/')))

    @property
    def excluded_param_types(self):
        """
        Gets all the types of excluded parameters. For each type the following are shown: the ID and the name.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/excludedParamTypes/')))

    @property
    def option_attack_policy(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionAttackPolicy/')))

    @property
    def option_default_policy(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionDefaultPolicy/')))

    @property
    def option_delay_in_ms(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionDelayInMs/')))

    @property
    def option_handle_anti_csrf_tokens(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionHandleAntiCSRFTokens/')))

    @property
    def option_host_per_scan(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionHostPerScan/')))

    @property
    def option_max_chart_time_in_mins(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionMaxChartTimeInMins/')))

    @property
    def option_max_results_to_list(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionMaxResultsToList/')))

    @property
    def option_max_rule_duration_in_mins(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionMaxRuleDurationInMins/')))

    @property
    def option_max_scan_duration_in_mins(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionMaxScanDurationInMins/')))

    @property
    def option_max_scans_in_ui(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionMaxScansInUI/')))

    @property
    def option_target_params_enabled_rpc(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionTargetParamsEnabledRPC/')))

    @property
    def option_target_params_injectable(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionTargetParamsInjectable/')))

    @property
    def option_thread_per_host(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionThreadPerHost/')))

    @property
    def option_add_query_param(self):
        """
        Tells whether or not the active scanner should add a query parameter to GET request that don't have parameters to start with.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionAddQueryParam/')))

    @property
    def option_allow_attack_on_start(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionAllowAttackOnStart/')))

    @property
    def option_inject_plugin_id_in_header(self):
        """
        Tells whether or not the active scanner should inject the HTTP request header X-ZAP-Scan-ID, with the ID of the scanner that's sending the requests.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionInjectPluginIdInHeader/')))

    @property
    def option_prompt_in_attack_mode(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionPromptInAttackMode/')))

    @property
    def option_prompt_to_clear_finished_scans(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionPromptToClearFinishedScans/')))

    @property
    def option_rescan_in_attack_mode(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionRescanInAttackMode/')))

    @property
    def option_scan_headers_all_requests(self):
        """
        Tells whether or not the HTTP Headers of all requests should be scanned. Not just requests that send parameters, through the query or request body.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionScanHeadersAllRequests/')))

    @property
    def option_scan_null_json_values(self):
        """
        Tells whether or not the active scanner should scan null JSON values.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionScanNullJsonValues/')))

    @property
    def option_show_advanced_dialog(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/view/optionShowAdvancedDialog/')))

    def scan(self, url=None, recurse=None, inscopeonly=None, scanpolicyname=None, method=None, postdata=None, contextid=None, apikey=''):
        """
        Runs the active scanner against the given URL or Context. Optionally, the 'recurse' parameter can be used to scan URLs under the given URL, the parameter 'inScopeOnly' can be used to constrain the scan to URLs that are in scope (ignored if a Context is specified), the parameter 'scanPolicyName' allows to specify the scan policy (if none is given it uses the default scan policy), the parameters 'method' and 'postData' allow to select a given request in conjunction with the given URL.
        """
        params = {'apikey': apikey}
        if url is not None:
            params['url'] = url
        if recurse is not None:
            params['recurse'] = recurse
        if inscopeonly is not None:
            params['inScopeOnly'] = inscopeonly
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        if method is not None:
            params['method'] = method
        if postdata is not None:
            params['postData'] = postdata
        if contextid is not None:
            params['contextId'] = contextid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/scan/', params)))

    def scan_as_user(self, url=None, contextid=None, userid=None, recurse=None, scanpolicyname=None, method=None, postdata=None, apikey=''):
        """
        Active Scans from the perspective of a User, obtained using the given Context ID and User ID. See 'scan' action for more details.
        """
        params = {'apikey': apikey}
        if url is not None:
            params['url'] = url
        if contextid is not None:
            params['contextId'] = contextid
        if userid is not None:
            params['userId'] = userid
        if recurse is not None:
            params['recurse'] = recurse
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        if method is not None:
            params['method'] = method
        if postdata is not None:
            params['postData'] = postdata
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/scanAsUser/', params)))

    def pause(self, scanid, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/pause/', {'scanId': scanid, 'apikey': apikey})))

    def resume(self, scanid, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/resume/', {'scanId': scanid, 'apikey': apikey})))

    def stop(self, scanid, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/stop/', {'scanId': scanid, 'apikey': apikey})))

    def remove_scan(self, scanid, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/removeScan/', {'scanId': scanid, 'apikey': apikey})))

    def pause_all_scans(self, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/pauseAllScans/', {'apikey': apikey})))

    def resume_all_scans(self, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/resumeAllScans/', {'apikey': apikey})))

    def stop_all_scans(self, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/stopAllScans/', {'apikey': apikey})))

    def remove_all_scans(self, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/removeAllScans/', {'apikey': apikey})))

    def clear_excluded_from_scan(self, apikey=''):
        """
        Clears the regexes of URLs excluded from the active scans.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/clearExcludedFromScan/', {'apikey': apikey})))

    def exclude_from_scan(self, regex, apikey=''):
        """
        Adds a regex of URLs that should be excluded from the active scans.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/excludeFromScan/', {'regex': regex, 'apikey': apikey})))

    def enable_all_scanners(self, scanpolicyname=None, apikey=''):
        """
        Enables all scan rules of the scan policy with the given name, or the default if none given.
        """
        params = {'apikey': apikey}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/enableAllScanners/', params)))

    def disable_all_scanners(self, scanpolicyname=None, apikey=''):
        """
        Disables all scan rules of the scan policy with the given name, or the default if none given.
        """
        params = {'apikey': apikey}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/disableAllScanners/', params)))

    def enable_scanners(self, ids, scanpolicyname=None, apikey=''):
        """
        Enables the scan rules with the given IDs (comma separated list of IDs) of the scan policy with the given name, or the default if none given.
        """
        params = {'ids': ids, 'apikey': apikey}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/enableScanners/', params)))

    def disable_scanners(self, ids, scanpolicyname=None, apikey=''):
        """
        Disables the scan rules with the given IDs (comma separated list of IDs) of the scan policy with the given name, or the default if none given.
        """
        params = {'ids': ids, 'apikey': apikey}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/disableScanners/', params)))

    def set_enabled_policies(self, ids, scanpolicyname=None, apikey=''):
        """
        
        """
        params = {'ids': ids, 'apikey': apikey}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setEnabledPolicies/', params)))

    def set_policy_attack_strength(self, id, attackstrength, scanpolicyname=None, apikey=''):
        """
        
        """
        params = {'id': id, 'attackStrength': attackstrength, 'apikey': apikey}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setPolicyAttackStrength/', params)))

    def set_policy_alert_threshold(self, id, alertthreshold, scanpolicyname=None, apikey=''):
        """
        
        """
        params = {'id': id, 'alertThreshold': alertthreshold, 'apikey': apikey}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setPolicyAlertThreshold/', params)))

    def set_scanner_attack_strength(self, id, attackstrength, scanpolicyname=None, apikey=''):
        """
        
        """
        params = {'id': id, 'attackStrength': attackstrength, 'apikey': apikey}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setScannerAttackStrength/', params)))

    def set_scanner_alert_threshold(self, id, alertthreshold, scanpolicyname=None, apikey=''):
        """
        
        """
        params = {'id': id, 'alertThreshold': alertthreshold, 'apikey': apikey}
        if scanpolicyname is not None:
            params['scanPolicyName'] = scanpolicyname
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setScannerAlertThreshold/', params)))

    def add_scan_policy(self, scanpolicyname, alertthreshold=None, attackstrength=None, apikey=''):
        """
        
        """
        params = {'scanPolicyName': scanpolicyname, 'apikey': apikey}
        if alertthreshold is not None:
            params['alertThreshold'] = alertthreshold
        if attackstrength is not None:
            params['attackStrength'] = attackstrength
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/addScanPolicy/', params)))

    def remove_scan_policy(self, scanpolicyname, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/removeScanPolicy/', {'scanPolicyName': scanpolicyname, 'apikey': apikey})))

    def update_scan_policy(self, scanpolicyname, alertthreshold=None, attackstrength=None, apikey=''):
        """
        
        """
        params = {'scanPolicyName': scanpolicyname, 'apikey': apikey}
        if alertthreshold is not None:
            params['alertThreshold'] = alertthreshold
        if attackstrength is not None:
            params['attackStrength'] = attackstrength
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/updateScanPolicy/', params)))

    def import_scan_policy(self, path, apikey=''):
        """
        Imports a Scan Policy using the given file system path.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/importScanPolicy/', {'path': path, 'apikey': apikey})))

    def add_excluded_param(self, name, type=None, url=None, apikey=''):
        """
        Adds a new parameter excluded from the scan, using the specified name. Optionally sets if the new entry applies to a specific URL (default, all URLs) and sets the ID of the type of the parameter (default, ID of any type). The type IDs can be obtained with the view excludedParamTypes. 
        """
        params = {'name': name, 'apikey': apikey}
        if type is not None:
            params['type'] = type
        if url is not None:
            params['url'] = url
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/addExcludedParam/', params)))

    def modify_excluded_param(self, idx, name=None, type=None, url=None, apikey=''):
        """
        Modifies a parameter excluded from the scan. Allows to modify the name, the URL and the type of parameter. The parameter is selected with its index, which can be obtained with the view excludedParams.
        """
        params = {'idx': idx, 'apikey': apikey}
        if name is not None:
            params['name'] = name
        if type is not None:
            params['type'] = type
        if url is not None:
            params['url'] = url
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/modifyExcludedParam/', params)))

    def remove_excluded_param(self, idx, apikey=''):
        """
        Removes a parameter excluded from the scan, with the given index. The index can be obtained with the view excludedParams.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/removeExcludedParam/', {'idx': idx, 'apikey': apikey})))

    def skip_scanner(self, scanid, scannerid, apikey=''):
        """
        Skips the scanner using the given IDs of the scan and the scanner.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/skipScanner/', {'scanId': scanid, 'scannerId': scannerid, 'apikey': apikey})))

    def set_option_attack_policy(self, string, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionAttackPolicy/', {'String': string, 'apikey': apikey})))

    def set_option_default_policy(self, string, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionDefaultPolicy/', {'String': string, 'apikey': apikey})))

    def set_option_add_query_param(self, boolean, apikey=''):
        """
        Sets whether or not the active scanner should add a query param to GET requests which do not have parameters to start with.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionAddQueryParam/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_allow_attack_on_start(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionAllowAttackOnStart/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_delay_in_ms(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionDelayInMs/', {'Integer': integer, 'apikey': apikey})))

    def set_option_handle_anti_csrf_tokens(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionHandleAntiCSRFTokens/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_host_per_scan(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionHostPerScan/', {'Integer': integer, 'apikey': apikey})))

    def set_option_inject_plugin_id_in_header(self, boolean, apikey=''):
        """
        Sets whether or not the active scanner should inject the HTTP request header X-ZAP-Scan-ID, with the ID of the scanner that's sending the requests.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionInjectPluginIdInHeader/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_max_chart_time_in_mins(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionMaxChartTimeInMins/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_results_to_list(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionMaxResultsToList/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_rule_duration_in_mins(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionMaxRuleDurationInMins/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_scan_duration_in_mins(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionMaxScanDurationInMins/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_scans_in_ui(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionMaxScansInUI/', {'Integer': integer, 'apikey': apikey})))

    def set_option_prompt_in_attack_mode(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionPromptInAttackMode/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_prompt_to_clear_finished_scans(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionPromptToClearFinishedScans/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_rescan_in_attack_mode(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionRescanInAttackMode/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_scan_headers_all_requests(self, boolean, apikey=''):
        """
        Sets whether or not the HTTP Headers of all requests should be scanned. Not just requests that send parameters, through the query or request body.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionScanHeadersAllRequests/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_scan_null_json_values(self, boolean, apikey=''):
        """
        Sets whether or not the active scanner should scan null JSON values.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionScanNullJsonValues/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_show_advanced_dialog(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionShowAdvancedDialog/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_target_params_enabled_rpc(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionTargetParamsEnabledRPC/', {'Integer': integer, 'apikey': apikey})))

    def set_option_target_params_injectable(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionTargetParamsInjectable/', {'Integer': integer, 'apikey': apikey})))

    def set_option_thread_per_host(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ascan/action/setOptionThreadPerHost/', {'Integer': integer, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2020 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class exportreport(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def formats(self):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'exportreport/view/formats/')))

    def generate(self, absolutepath, fileextension, sourcedetails, alertseverity, alertdetails, scanid=None, includepassivealerts=None, apikey=''):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'absolutePath': absolutepath, 'fileExtension': fileextension, 'sourceDetails': sourcedetails, 'alertSeverity': alertseverity, 'alertDetails': alertdetails, 'apikey': apikey}
        if scanid is not None:
            params['scanId'] = scanid
        if includepassivealerts is not None:
            params['includePassiveAlerts'] = includepassivealerts
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'exportreport/action/generate/', params)))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class users(object):

    def __init__(self, zap):
        self.zap = zap

    def users_list(self, contextid=None):
        """
        Gets a list of users that belong to the context with the given ID, or all users if none provided.
        """
        params = {}
        if contextid is not None:
            params['contextId'] = contextid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/view/usersList/', params)))

    def get_user_by_id(self, contextid, userid):
        """
        Gets the data of the user with the given ID that belongs to the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/view/getUserById/', {'contextId': contextid, 'userId': userid})))

    def get_authentication_credentials_config_params(self, contextid):
        """
        Gets the configuration parameters for the credentials of the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/view/getAuthenticationCredentialsConfigParams/', {'contextId': contextid})))

    def get_authentication_credentials(self, contextid, userid):
        """
        Gets the authentication credentials of the user with given ID that belongs to the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/view/getAuthenticationCredentials/', {'contextId': contextid, 'userId': userid})))

    def get_authentication_state(self, contextid, userid):
        """
        Gets the authentication state information for the user identified by the Context and User Ids.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/view/getAuthenticationState/', {'contextId': contextid, 'userId': userid})))

    def get_authentication_session(self, contextid, userid):
        """
        Gets the authentication session information for the user identified by the Context and User Ids, e.g. cookies and realm credentials.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/view/getAuthenticationSession/', {'contextId': contextid, 'userId': userid})))

    def new_user(self, contextid, name, apikey=''):
        """
        Creates a new user with the given name for the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/action/newUser/', {'contextId': contextid, 'name': name, 'apikey': apikey})))

    def remove_user(self, contextid, userid, apikey=''):
        """
        Removes the user with the given ID that belongs to the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/action/removeUser/', {'contextId': contextid, 'userId': userid, 'apikey': apikey})))

    def set_user_enabled(self, contextid, userid, enabled, apikey=''):
        """
        Sets whether or not the user, with the given ID that belongs to the context with the given ID, should be enabled.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/action/setUserEnabled/', {'contextId': contextid, 'userId': userid, 'enabled': enabled, 'apikey': apikey})))

    def set_user_name(self, contextid, userid, name, apikey=''):
        """
        Renames the user with the given ID that belongs to the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/action/setUserName/', {'contextId': contextid, 'userId': userid, 'name': name, 'apikey': apikey})))

    def set_authentication_credentials(self, contextid, userid, authcredentialsconfigparams=None, apikey=''):
        """
        Sets the authentication credentials for the user with the given ID that belongs to the context with the given ID.
        """
        params = {'contextId': contextid, 'userId': userid, 'apikey': apikey}
        if authcredentialsconfigparams is not None:
            params['authCredentialsConfigParams'] = authcredentialsconfigparams
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/action/setAuthenticationCredentials/', params)))

    def authenticate_as_user(self, contextid, userid, apikey=''):
        """
        Tries to authenticate as the identified user, returning the authentication request and whether it appears to have succeeded.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/action/authenticateAsUser/', {'contextId': contextid, 'userId': userid, 'apikey': apikey})))

    def poll_as_user(self, contextid, userid, apikey=''):
        """
        Tries to poll as the identified user, returning the authentication request and whether it appears to have succeeded. This will only work if the polling verification strategy has been configured.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/action/pollAsUser/', {'contextId': contextid, 'userId': userid, 'apikey': apikey})))

    def set_authentication_state(self, contextid, userid, lastpollresult=None, lastpolltimeinms=None, requestssincelastpoll=None, apikey=''):
        """
        Sets fields in the authentication state for the user identified by the Context and User Ids.
        """
        params = {'contextId': contextid, 'userId': userid, 'apikey': apikey}
        if lastpollresult is not None:
            params['lastPollResult'] = lastpollresult
        if lastpolltimeinms is not None:
            params['lastPollTimeInMs'] = lastpolltimeinms
        if requestssincelastpoll is not None:
            params['requestsSinceLastPoll'] = requestssincelastpoll
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/action/setAuthenticationState/', params)))

    def set_cookie(self, contextid, userid, domain, name, value, path=None, secure=None, apikey=''):
        """
        Sets the specified cookie for the user identified by the Context and User Ids.
        """
        params = {'contextId': contextid, 'userId': userid, 'domain': domain, 'name': name, 'value': value, 'apikey': apikey}
        if path is not None:
            params['path'] = path
        if secure is not None:
            params['secure'] = secure
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'users/action/setCookie/', params)))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class autoupdate(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def latest_version_number(self):
        """
        Returns the latest version number
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/latestVersionNumber/')))

    @property
    def is_latest_version(self):
        """
        Returns 'true' if ZAP is on the latest version
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/isLatestVersion/')))

    @property
    def installed_addons(self):
        """
        Return a list of all of the installed add-ons
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/installedAddons/')))

    @property
    def local_addons(self):
        """
        Returns a list with all local add-ons, installed or not.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/localAddons/')))

    @property
    def new_addons(self):
        """
        Return a list of any add-ons that have been added to the Marketplace since the last check for updates
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/newAddons/')))

    @property
    def updated_addons(self):
        """
        Return a list of any add-ons that have been changed in the Marketplace since the last check for updates
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/updatedAddons/')))

    @property
    def marketplace_addons(self):
        """
        Return a list of all of the add-ons on the ZAP Marketplace (this information is read once and then cached)
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/marketplaceAddons/')))

    @property
    def option_addon_directories(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionAddonDirectories/')))

    @property
    def option_day_last_checked(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionDayLastChecked/')))

    @property
    def option_day_last_install_warned(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionDayLastInstallWarned/')))

    @property
    def option_day_last_update_warned(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionDayLastUpdateWarned/')))

    @property
    def option_download_directory(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionDownloadDirectory/')))

    @property
    def option_check_addon_updates(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionCheckAddonUpdates/')))

    @property
    def option_check_on_start(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionCheckOnStart/')))

    @property
    def option_download_new_release(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionDownloadNewRelease/')))

    @property
    def option_install_addon_updates(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionInstallAddonUpdates/')))

    @property
    def option_install_scanner_rules(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionInstallScannerRules/')))

    @property
    def option_report_alpha_addons(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionReportAlphaAddons/')))

    @property
    def option_report_beta_addons(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionReportBetaAddons/')))

    @property
    def option_report_release_addons(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/view/optionReportReleaseAddons/')))

    def download_latest_release(self, apikey=''):
        """
        Downloads the latest release, if any 
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/downloadLatestRelease/', {'apikey': apikey})))

    def install_addon(self, id, apikey=''):
        """
        Installs or updates the specified add-on, returning when complete (i.e. not asynchronously)
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/installAddon/', {'id': id, 'apikey': apikey})))

    def install_local_addon(self, file, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/installLocalAddon/', {'file': file, 'apikey': apikey})))

    def uninstall_addon(self, id, apikey=''):
        """
        Uninstalls the specified add-on 
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/uninstallAddon/', {'id': id, 'apikey': apikey})))

    def set_option_check_addon_updates(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/setOptionCheckAddonUpdates/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_check_on_start(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/setOptionCheckOnStart/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_download_new_release(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/setOptionDownloadNewRelease/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_install_addon_updates(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/setOptionInstallAddonUpdates/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_install_scanner_rules(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/setOptionInstallScannerRules/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_report_alpha_addons(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/setOptionReportAlphaAddons/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_report_beta_addons(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/setOptionReportBetaAddons/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_report_release_addons(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'autoupdate/action/setOptionReportReleaseAddons/', {'Boolean': boolean, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class forcedUser(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def is_forced_user_mode_enabled(self):
        """
        Returns 'true' if 'forced user' mode is enabled, 'false' otherwise
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'forcedUser/view/isForcedUserModeEnabled/')))

    def get_forced_user(self, contextid):
        """
        Gets the user (ID) set as 'forced user' for the given context (ID)
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'forcedUser/view/getForcedUser/', {'contextId': contextid})))

    def set_forced_user(self, contextid, userid, apikey=''):
        """
        Sets the user (ID) that should be used in 'forced user' mode for the given context (ID)
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'forcedUser/action/setForcedUser/', {'contextId': contextid, 'userId': userid, 'apikey': apikey})))

    def set_forced_user_mode_enabled(self, boolean, apikey=''):
        """
        Sets if 'forced user' mode should be enabled or not
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'forcedUser/action/setForcedUserModeEnabled/', {'boolean': boolean, 'apikey': apikey})))



#!/usr/bin/env python
"""
Standard build script.
"""

__docformat__ = 'restructuredtext'


try:
    from setuptools import setup, find_packages
except ImportError:
    print('You must have setuptools installed to use setup.py. Exiting...')
    raise SystemExit(1)


install_dependencies = (
    'requests',
    'six'
)
test_requirements = (
    'mock',
    'pyhamcrest',
    'pylama',
    'pytest',
    'requests_mock'
)
setup(
    name="python-owasp-zap-v2.4",
    version="0.0.21",
    description="OWASP ZAP 2.12 API client",
    long_description="OWASP Zed Attack Proxy 2.12 API Python client (the 2.4 package name has been kept to make it easier to upgrade)",
    author="ZAP development team",
    author_email='',
    url="https://www.zaproxy.org/",
    download_url="https://github.com/zaproxy/zap-api-python/releases/tag/0.0.21",
    platforms=['any'],
    license="ASL2.0",
    package_dir={
        '': 'src',
    },
    packages=find_packages('src'),
    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Development Status :: 5 - Production/Stable',
        'Topic :: Security',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    install_requires=install_dependencies,
    tests_require=test_requirements,
    extras_require={'tests': test_requirements}
)



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class accessControl(object):

    def __init__(self, zap):
        self.zap = zap

    def get_scan_progress(self, contextid):
        """
        Gets the Access Control scan progress (percentage integer) for the given context ID.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'accessControl/view/getScanProgress/', {'contextId': contextid})))

    def get_scan_status(self, contextid):
        """
        Gets the Access Control scan status (description string) for the given context ID.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'accessControl/view/getScanStatus/', {'contextId': contextid})))

    def scan(self, contextid, userid, scanasunauthuser=None, raisealert=None, alertrisklevel=None, apikey=''):
        """
        Starts an Access Control scan with the given context ID and user ID. (Optional parameters: user ID for Unauthenticated user, boolean identifying whether or not Alerts are raised, and the Risk level for the Alerts.) [This assumes the Access Control rules were previously established via ZAP gui and the necessary Context exported/imported.]
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'contextId': contextid, 'userId': userid, 'apikey': apikey}
        if scanasunauthuser is not None:
            params['scanAsUnAuthUser'] = scanasunauthuser
        if raisealert is not None:
            params['raiseAlert'] = raisealert
        if alertrisklevel is not None:
            params['alertRiskLevel'] = alertrisklevel
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'accessControl/action/scan/', params)))

    def write_htm_lreport(self, contextid, filename, apikey=''):
        """
        Generates an Access Control report for the given context ID and saves it based on the provided filename (path). 
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'accessControl/action/writeHTMLreport/', {'contextId': contextid, 'fileName': filename, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class context(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def context_list(self):
        """
        List context names of current session
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/view/contextList/')))

    def exclude_regexs(self, contextname):
        """
        List excluded regexs for context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/view/excludeRegexs/', {'contextName': contextname})))

    def include_regexs(self, contextname):
        """
        List included regexs for context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/view/includeRegexs/', {'contextName': contextname})))

    def context(self, contextname):
        """
        List the information about the named context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/view/context/', {'contextName': contextname})))

    @property
    def technology_list(self):
        """
        Lists the names of all built in technologies
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/view/technologyList/')))

    def included_technology_list(self, contextname):
        """
        Lists the names of all technologies included in a context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/view/includedTechnologyList/', {'contextName': contextname})))

    def excluded_technology_list(self, contextname):
        """
        Lists the names of all technologies excluded from a context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/view/excludedTechnologyList/', {'contextName': contextname})))

    def urls(self, contextname):
        """
        Lists the URLs accessed through/by ZAP, that belong to the context with the given name.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/view/urls/', {'contextName': contextname})))

    def exclude_from_context(self, contextname, regex, apikey=''):
        """
        Add exclude regex to context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/excludeFromContext/', {'contextName': contextname, 'regex': regex, 'apikey': apikey})))

    def include_in_context(self, contextname, regex, apikey=''):
        """
        Add include regex to context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/includeInContext/', {'contextName': contextname, 'regex': regex, 'apikey': apikey})))

    def set_context_regexs(self, contextname, incregexs, excregexs, apikey=''):
        """
        Set the regexs to include and exclude for a context, both supplied as JSON string arrays
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/setContextRegexs/', {'contextName': contextname, 'incRegexs': incregexs, 'excRegexs': excregexs, 'apikey': apikey})))

    def set_context_checking_strategy(self, contextname, checkingstrategy, pollurl=None, polldata=None, pollheaders=None, pollfrequency=None, pollfrequencyunits=None, apikey=''):
        """
        Set the checking strategy for a context - this defines how ZAP checks that a request is authenticated
        """
        params = {'contextName': contextname, 'checkingStrategy': checkingstrategy, 'apikey': apikey}
        if pollurl is not None:
            params['pollUrl'] = pollurl
        if polldata is not None:
            params['pollData'] = polldata
        if pollheaders is not None:
            params['pollHeaders'] = pollheaders
        if pollfrequency is not None:
            params['pollFrequency'] = pollfrequency
        if pollfrequencyunits is not None:
            params['pollFrequencyUnits'] = pollfrequencyunits
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/setContextCheckingStrategy/', params)))

    def new_context(self, contextname, apikey=''):
        """
        Creates a new context with the given name in the current session
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/newContext/', {'contextName': contextname, 'apikey': apikey})))

    def remove_context(self, contextname, apikey=''):
        """
        Removes a context in the current session
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/removeContext/', {'contextName': contextname, 'apikey': apikey})))

    def export_context(self, contextname, contextfile, apikey=''):
        """
        Exports the context with the given name to a file. If a relative file path is specified it will be resolved against the "contexts" directory in ZAP "home" dir.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/exportContext/', {'contextName': contextname, 'contextFile': contextfile, 'apikey': apikey})))

    def import_context(self, contextfile, apikey=''):
        """
        Imports a context from a file. If a relative file path is specified it will be resolved against the "contexts" directory in ZAP "home" dir.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/importContext/', {'contextFile': contextfile, 'apikey': apikey})))

    def include_context_technologies(self, contextname, technologynames, apikey=''):
        """
        Includes technologies with the given names, separated by a comma, to a context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/includeContextTechnologies/', {'contextName': contextname, 'technologyNames': technologynames, 'apikey': apikey})))

    def include_all_context_technologies(self, contextname, apikey=''):
        """
        Includes all built in technologies in to a context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/includeAllContextTechnologies/', {'contextName': contextname, 'apikey': apikey})))

    def exclude_context_technologies(self, contextname, technologynames, apikey=''):
        """
        Excludes technologies with the given names, separated by a comma, from a context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/excludeContextTechnologies/', {'contextName': contextname, 'technologyNames': technologynames, 'apikey': apikey})))

    def exclude_all_context_technologies(self, contextname, apikey=''):
        """
        Excludes all built in technologies from a context
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/excludeAllContextTechnologies/', {'contextName': contextname, 'apikey': apikey})))

    def set_context_in_scope(self, contextname, booleaninscope, apikey=''):
        """
        Sets a context to in scope (contexts are in scope by default)
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'context/action/setContextInScope/', {'contextName': contextname, 'booleanInScope': booleaninscope, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class params(object):

    def __init__(self, zap):
        self.zap = zap

    def params(self, site=None):
        """
        Shows the parameters for the specified site, or for all sites if the site is not specified
        """
        params = {}
        if site is not None:
            params['site'] = site
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'params/view/params/', params)))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class graphql(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def option_args_type(self):
        """
        Returns how arguments are currently specified.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/view/optionArgsType/')))

    @property
    def option_lenient_max_query_depth_enabled(self):
        """
        Returns whether or not lenient maximum query generation depth is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/view/optionLenientMaxQueryDepthEnabled/')))

    @property
    def option_max_additional_query_depth(self):
        """
        Returns the current maximum additional query generation depth.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/view/optionMaxAdditionalQueryDepth/')))

    @property
    def option_max_args_depth(self):
        """
        Returns the current maximum arguments generation depth.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/view/optionMaxArgsDepth/')))

    @property
    def option_max_query_depth(self):
        """
        Returns the current maximum query generation depth.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/view/optionMaxQueryDepth/')))

    @property
    def option_optional_args_enabled(self):
        """
        Returns whether or not optional arguments are currently specified.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/view/optionOptionalArgsEnabled/')))

    @property
    def option_query_split_type(self):
        """
        Returns the current level for which a single query is generated.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/view/optionQuerySplitType/')))

    @property
    def option_request_method(self):
        """
        Returns the current request method.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/view/optionRequestMethod/')))

    def import_file(self, endurl, file, apikey=''):
        """
        Imports a GraphQL Schema from a File.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/action/importFile/', {'endurl': endurl, 'file': file, 'apikey': apikey})))

    def import_url(self, endurl, url=None, apikey=''):
        """
        Imports a GraphQL Schema from a URL.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'endurl': endurl, 'apikey': apikey}
        if url is not None:
            params['url'] = url
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/action/importUrl/', params)))

    def set_option_args_type(self, string, apikey=''):
        """
        Sets how arguments are specified.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/action/setOptionArgsType/', {'String': string, 'apikey': apikey})))

    def set_option_query_split_type(self, string, apikey=''):
        """
        Sets the level for which a single query is generated.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/action/setOptionQuerySplitType/', {'String': string, 'apikey': apikey})))

    def set_option_request_method(self, string, apikey=''):
        """
        Sets the request method.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/action/setOptionRequestMethod/', {'String': string, 'apikey': apikey})))

    def set_option_lenient_max_query_depth_enabled(self, boolean, apikey=''):
        """
        Sets whether or not Maximum Query Depth is enforced leniently.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/action/setOptionLenientMaxQueryDepthEnabled/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_max_additional_query_depth(self, integer, apikey=''):
        """
        Sets the maximum additional query generation depth (used if enforced leniently).
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/action/setOptionMaxAdditionalQueryDepth/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_args_depth(self, integer, apikey=''):
        """
        Sets the maximum arguments generation depth.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/action/setOptionMaxArgsDepth/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_query_depth(self, integer, apikey=''):
        """
        Sets the maximum query generation depth.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/action/setOptionMaxQueryDepth/', {'Integer': integer, 'apikey': apikey})))

    def set_option_optional_args_enabled(self, boolean, apikey=''):
        """
        Sets whether or not Optional Arguments should be specified.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'graphql/action/setOptionOptionalArgsEnabled/', {'Boolean': boolean, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class pscan(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def scan_only_in_scope(self):
        """
        Tells whether or not the passive scan should be performed only on messages that are in scope.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/view/scanOnlyInScope/')))

    @property
    def records_to_scan(self):
        """
        The number of records the passive scanner still has to scan
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/view/recordsToScan/')))

    @property
    def scanners(self):
        """
        Lists all passive scan rules with their ID, name, enabled state, and alert threshold.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/view/scanners/')))

    @property
    def current_rule(self):
        """
        Show information about the passive scan rule currently being run (if any).
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/view/currentRule/')))

    @property
    def current_tasks(self):
        """
        Show information about the passive scan tasks currently being run (if any).
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/view/currentTasks/')))

    @property
    def max_alerts_per_rule(self):
        """
        Gets the maximum number of alerts a passive scan rule should raise.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/view/maxAlertsPerRule/')))

    def set_enabled(self, enabled, apikey=''):
        """
        Sets whether or not the passive scanning is enabled (Note: the enabled state is not persisted).
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/setEnabled/', {'enabled': enabled, 'apikey': apikey})))

    def set_scan_only_in_scope(self, onlyinscope, apikey=''):
        """
        Sets whether or not the passive scan should be performed only on messages that are in scope.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/setScanOnlyInScope/', {'onlyInScope': onlyinscope, 'apikey': apikey})))

    def enable_all_scanners(self, apikey=''):
        """
        Enables all passive scan rules
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/enableAllScanners/', {'apikey': apikey})))

    def disable_all_scanners(self, apikey=''):
        """
        Disables all passive scan rules
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/disableAllScanners/', {'apikey': apikey})))

    def enable_scanners(self, ids, apikey=''):
        """
        Enables all passive scan rules with the given IDs (comma separated list of IDs)
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/enableScanners/', {'ids': ids, 'apikey': apikey})))

    def disable_scanners(self, ids, apikey=''):
        """
        Disables all passive scan rules with the given IDs (comma separated list of IDs)
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/disableScanners/', {'ids': ids, 'apikey': apikey})))

    def set_scanner_alert_threshold(self, id, alertthreshold, apikey=''):
        """
        Sets the alert threshold of the passive scanner with the given ID, accepted values for alert threshold: OFF, DEFAULT, LOW, MEDIUM and HIGH
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/setScannerAlertThreshold/', {'id': id, 'alertThreshold': alertthreshold, 'apikey': apikey})))

    def set_max_alerts_per_rule(self, maxalerts, apikey=''):
        """
        Sets the maximum number of alerts a passive scan rule should raise.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/setMaxAlertsPerRule/', {'maxAlerts': maxalerts, 'apikey': apikey})))

    def disable_all_tags(self, apikey=''):
        """
        Disables all passive scan tags.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/disableAllTags/', {'apikey': apikey})))

    def enable_all_tags(self, apikey=''):
        """
        Enables all passive scan tags.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/enableAllTags/', {'apikey': apikey})))

    def clear_queue(self, apikey=''):
        """
        Clears the passive scan queue.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'pscan/action/clearQueue/', {'apikey': apikey})))
